
const localStorageGameId = "terrassumptions:gameId";
const localStoragePlayerName = "terrassumptions:playerName";
const localStoragePlayerId = "terrassumptions:playerId";

const localStorageTimer = "terrassumptions:timer";

const localStoragePanoLat = "terrassumptions:pano:lat";
const localStoragePanoLng = "terrassumptions:pano:lng";

const localStoragePanoHeading = "terrassumptions:pano:heading";
const localStoragePanoPitch = "terrassumptions:pano:pitch";

export const hasSavedGameInfo = () => (
  localStorage.getItem(localStorageGameId) !== null &&
  localStorage.getItem(localStoragePlayerName) !== null &&
  localStorage.getItem(localStoragePlayerId) !== null
)

export const saveGameInfoToLocalStorage = (gameId, playerName, playerId) => {
  localStorage.setItem(localStorageGameId, gameId);
  localStorage.setItem(localStoragePlayerName, playerName);
  localStorage.setItem(localStoragePlayerId, playerId);
}

export const saveTimerToLocalStorage = (timer) => {
  localStorage.setItem(localStorageTimer, timer.toString());
}

export const savePanoPositionToLocalStorage = (lat, lng) => {
  localStorage.setItem(localStoragePanoLat, lat.toString());
  localStorage.setItem(localStoragePanoLng, lng.toString());
}

export const savePanoPovToLocalStorage = (heading, pitch) => {
  localStorage.setItem(localStoragePanoHeading, heading.toString());
  localStorage.setItem(localStoragePanoPitch, pitch.toString());
}

export const clearGameInfoFromLocalStorage = () => {
  localStorage.removeItem(localStorageGameId);
  localStorage.removeItem(localStoragePlayerName);
  localStorage.removeItem(localStoragePlayerId);
}

export const clearRoundInfoFromLocalStorage = () => {
  localStorage.removeItem(localStorageTimer);
  localStorage.removeItem(localStoragePanoLat);
  localStorage.removeItem(localStoragePanoLng);
  localStorage.removeItem(localStoragePanoHeading);
  localStorage.removeItem(localStoragePanoPitch);
}

export const getGameInfoFromLocalStorage = () => ({
  gameId: localStorage.getItem(localStorageGameId),
  playerName: localStorage.getItem(localStoragePlayerName),
  playerId: localStorage.getItem(localStoragePlayerId),
})

const parseFloatFromStorage = key => {
  const val = localStorage.getItem(key);
  return val === null ? null : Number.parseFloat(val);
}

export const getRoundInfoFromLocalStorage = () => {
  const timer = localStorage.getItem(localStorageTimer);
  const position = {
    lat: parseFloatFromStorage(localStoragePanoLat),
    lng: parseFloatFromStorage(localStoragePanoLng),
  };
  const pov = {
    heading: parseFloatFromStorage(localStoragePanoHeading),
    pitch: parseFloatFromStorage(localStoragePanoPitch),
  };

  return {
    timer: timer !== null ? Number.parseInt(timer) : null,
    position: position.lat !== null && position.lng !== null ? position : null,
    pov: pov.heading !== null && pov.pitch !== null ? pov : null,
  }
};
